package cn.jxufe.iet.code0501.util;

import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.os.Environment;


import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.List;

import cn.jxufe.iet.code0501.R;
import cn.jxufe.iet.code0501.bean.School;


/**
 * Created by ZHG on 2017/01/13.
 * 从模拟服务端获取数据类
 */
public class GetSQLite {
    public GetSQLite(Context context){
        Global.initPreferences = context.getSharedPreferences("dbInfo",
                Context.MODE_PRIVATE);// 初始化数据库保存信息
        boolean isInitDB=Global.initPreferences.getBoolean("initDB", false);
        if(!isInitDB){//如果没有初始化数据库
            initDB(context);//如果是第一次使用，则执行初始化
            Global.initPreferences.edit().putString("dbPath", Global.DB_PATH).commit();
            Global.initPreferences.edit().putBoolean("initDB",true).commit();//保存数据并提交
        }else{
            Global.DB_PATH=Global.initPreferences.getString("dbPath","");
        }
        System.out.println("本地数据库路径："+Global.DB_PATH);
    }

    public SQLiteDatabase getDataBase(Context context) {//打开指定的数据库
        return Global.db=context.openOrCreateDatabase(Global.DB_PATH, Context.MODE_PRIVATE, null);	//打开数据库
    }

    public List<String> getField(Context context, String sql) {//获取数据库表中某一字段的值的集合
        List<String> fields = new ArrayList<String>();
        SQLiteDatabase db=getDataBase(context);
        Cursor cursor = db.rawQuery(sql, null);
        while (cursor.moveToNext()) {
            fields.add(cursor.getString(0));
        }
        db.close();
        return fields;
    }
    //根据地区获取该地区下的所有学校信息
    public List<School> getSchoolsByArea(Context context, String sql, String[] args){
        List<School> schools=new ArrayList<School>();
        SQLiteDatabase db=getDataBase(context);
        Cursor cursor=db.rawQuery(sql,args);
        while(cursor.moveToNext()){
            School school=new School();
            school.setSchoolName(cursor.getString(cursor.getColumnIndex(School.SCHOOL_NAME)));
            school.setSchoolCode(cursor.getInt(cursor.getColumnIndex(School.SCHOOL_CODE)));
            school.setSchoolId(cursor.getInt(cursor.getColumnIndex(School.SCHOOL_ID)));
            schools.add(school);
        }
        cursor.close();
        db.close();
        return schools;
    }


    //根据批次名称获取批次Id
    public int getBatchId(String batchName){
        String[] batchNames=new String[]{"不限", "一本", "二本", "三本", "专科", "提前" };
        for(int i=0;i<batchNames.length;i++){
            if(batchName.equals(batchNames[i])){
                return i;
            }
        }
        return 0;
    }
    //根据类别名称获取类别Id
    public int getCategoryId(String categoryName){
        String[] categoryNames=new String[]{ "不限", "文史",  "理工", "综合类","艺术类", "体育"};
        for(int i=0;i<categoryNames.length;i++){
            if(categoryName.equals(categoryNames[i])){
                return i;
            }
        }
        return 0;
    }
    //根据地区名获取地区Id
    public int getAreaId(Context context, String areaName){
        SQLiteDatabase db=getDataBase(context);
        Cursor cursor=db.rawQuery("select areaId from area where areaName=?",new String[]{areaName});
        while(cursor.moveToNext()){
            return cursor.getInt(cursor.getColumnIndex("areaId"));
        }
        db.close();
        return -1;
    }
    //根据地区Id获取地区名
    public String getAreaName(Context context, String areaId){
        SQLiteDatabase db=getDataBase(context);
        Cursor cursor=db.rawQuery("select Name from bkt_area where ID=?",new String[]{areaId});
        while(cursor.moveToNext()){
            return cursor.getString(cursor.getColumnIndex("Name"));
        }
        db.close();
        return "";
    }

    public void initDB(Context context) {//初始化数据库
        File externalDir = context
                .getExternalFilesDir(Environment.DIRECTORY_DOWNLOADS);//存储路径
        String dbPath= externalDir.getAbsolutePath() + File.separator
                + "db";//在该路径下创建一个db文件夹
        File dir = new File(dbPath);
        if (!dir.exists()) {// 如果文件夹不存在，则创建文件夹
            dir.mkdir();//创建文件夹
        }
        File file = new File(dir.getPath(), Global.DB_NAME);//定义数据库文件
        if (!file.exists()) {//如果文件不存在，则创建文件
            try {
                file.createNewFile();//创建文件
            } catch (IOException e) {
                System.out.println("创建文件时出错！");
                e.printStackTrace();
            }
            copyFile(context, R.raw.bkt, file);//复制资源，将raw文件夹下的资源复制到存储卡中
        }
        Global.DB_PATH=file.getAbsolutePath();//获取数据库的路径
    }
    public void copyFile(Context context, int resId, File file){//将R.raw中的数据库文件复制到存储卡中
        try {
            InputStream is = context.getResources().openRawResource(R.raw.bkt);//打开文件对应的输入流
            FileOutputStream fos = new FileOutputStream(file);//打开文件对应的输出流
            byte[] buffer = new byte[1024];
            int hasRead = 0;
            while ((hasRead = is.read(buffer)) != -1) {
                fos.write(buffer, 0, hasRead);
            }
            fos.close();
            is.close();// 关闭资源
        } catch (Exception e) {
            System.out.println("复制文件时出错啦！");
        }
    }


    /*
   private String[] provinces = new String[]{"上海", "浙江", "江西", "北京"};
    private String[][] schoollists=new String[][]{{"复旦大学","上海中医药大学","同济大学","上海大学","上海交通大学","上海财经大学"},
            {"浙江大学","杭州电子科技大学","杭州师范大学","浙江财经学院","浙江传媒学院","浙江工商大学"},
            {"南昌大学","江西师范大学","江西农业大学","江西财经大学","华东交通大学","东华理工大学"},
            {"北京大学","清华大学","中国人民大学","北京交通大学","北京航空航天大学","北京理工大学"}};
    *//*
       把省份数据封装成集合，为后面调用数据库数据替换作准备
        *//*
    public List<String> setProvince(){
        List<String> provinces=new ArrayList<>();
        provinces.add("上海");
        provinces.add("浙江");
        provinces.add("江西");
        provinces.add("北京");
        return provinces;
    }
    *//*
  把学校信息封装成集合，为后面调用数据库数据替换做准备
   *//*
    public List<School> setSchoolList(){
        List<School> list=new ArrayList<>();
        for (int i=0;i<schoollists.length;i++){
            for(int j=0;j<schoollists[i].length;j++){
                School school=new School();
                school.setAreaName(provinces[i]);
                school.setSchoolName(schoollists[i][j]);
                list.add(school);
            }
        }
   return list;
    }*/
}
